pilas.motores.motor_qt.Motor

Package pilas :: Package motores :: Module motor_qt :: Class Motor |
[hide private]
[frames] | no frames]

# Class Motor

source code

    object --+
             |
            Motor

Representa la ventana principal de pilas.

Esta clase construirá el objeto apuntado por el atributo ``pilas.motor``, asi que será el representante de todas las funcionalidades multimedia.

Internamente, este motor, tratará de usar OpenGl para acelerar el dibujado en pantalla si la tarjeta de video lo soporta.

Instance Methods | [hide private]
__init__(self, usar_motor, permitir_depuracion, audio) x.__init__(...) initializes x; see help(type(x)) for signature | source code
_iniciar_aplicacion(self) | source code
_inicializar_variables(self) | source code
_inicializar_sistema_de_audio(self, audio) | source code
terminar(self) | source code
iniciar_ventana(self, ancho, alto, titulo, pantalla_completa, gestor_escenas, rendimiento) | source code
modificar_ventana(self, ancho, alto, titulo, pantalla_completa) | source code
ocultar_puntero_del_mouse(self) | source code
mostrar_puntero_del_mouse(self) | source code
ejecutar_bucle_principal(self, mundo, ignorar_errores) | source code
definir_centro_de_la_camara(self, x, y) | source code
obtener_centro_de_la_camara(self) | source code
centro_fisico(self) Centro de la ventana para situar el punto (0, 0) | source code
obtener_area(self) | source code
obtener_area_de_texto(self, texto, magnitud=10, vertical=False, fuente=None) | source code
obtener_actor(self, imagen, x, y) | source code
obtener_texto(self, texto, magnitud, vertical=False, fuente=None) | source code
obtener_grilla(self, ruta, columnas, filas) | source code
cargar_sonido(self, ruta) | source code
cargar_musica(self, ruta) | source code
deshabilitar_sonido(self, estado=True) | source code
deshabilitar_musica(self, estado=True) | source code
cargar_imagen(self, ruta) | source code
obtener_lienzo(self) | source code
obtener_superficie(self, ancho, alto) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, usar_motor, permitir_depuracion, audio) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)